MemoryPressureLevel

Enum MemoryPressureLevel 

pub enum MemoryPressureLevel {
    None = 0,
    Moderate = 1,
    Critical = 2,
}
Memory pressure level for the MemoryPressureNotification. None hints V8 that there is no memory pressure. Moderate hints V8 to speed up incremental garbage collection at the cost of higher latency due to garbage collection pauses. Critical hints V8 to free memory as soon as possible. Garbage collection pauses at this level will be large.

Variants



None = 0



Moderate = 1



Critical = 2