StackFrame

Struct StackFrame 

pub struct StackFrame(/* private fields */);
A single JavaScript stack frame.

Implementations

Source

impl StackFrame

pub fn get_line_number(&self) -> usize

Returns the number, 1-based, of the line for the associated function call. This method will return Message::kNoLineNumberInfo if it is unable to retrieve the line number, or if kLineNumber was not passed as an option when capturing the StackTrace.

pub fn get_column(&self) -> usize

Returns the 1-based column offset on the line for the associated function call. This method will return Message::kNoColumnInfo if it is unable to retrieve the column number, or if kColumnOffset was not passed as an option when capturing the StackTrace.

pub fn get_script_id(&self) -> usize

Returns the id of the script for the function for this StackFrame. This method will return Message::kNoScriptIdInfo if it is unable to retrieve the script id, or if kScriptId was not passed as an option when capturing the StackTrace.

pub fn get_script_name<'s>( &self, scope: &mut HandleScope<'s>, ) -> Option<Local<'s, String>>

Returns the name of the resource that contains the script for the function for this StackFrame.

pub fn get_script_name_or_source_url<'s>( &self, scope: &mut HandleScope<'s>, ) -> Option<Local<'s, String>>

Returns the name of the resource that contains the script for the function for this StackFrame or sourceURL value if the script name is undefined and its source ends with //# sourceURL=… string or deprecated //@ sourceURL=… string.

pub fn get_function_name<'s>( &self, scope: &mut HandleScope<'s>, ) -> Option<Local<'s, String>>

Returns the name of the function associated with this stack frame.

pub fn is_eval(&self) -> bool

Returns whether or not the associated function is compiled via a call to eval().

pub fn is_constructor(&self) -> bool

Returns whether or not the associated function is called as a constructor via “new”.

pub fn is_wasm(&self) -> bool

Returns whether or not the associated functions is defined in wasm.

pub fn is_user_javascript(&self) -> bool

Returns whether or not the associated function is defined by the user.